# AutoNN

[![Unittest](https://github.com/Universal-Analysis/autonn/actions/workflows/python-test.yml/badge.svg)](https://github.com/Universal-Analysis/autonn/actions/workflows/python-test.yml)


## Development Guide

* Install EditorConfig plugin within your IDE

